/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataHcpPackerIterationConfig extends cdktf.TerraformMetaArguments {
    /**
    * The slug of the HCP Packer Registry bucket to pull from.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.78.0/docs/data-sources/packer_iteration#bucket_name DataHcpPackerIteration#bucket_name}
    */
    readonly bucketName: string;
    /**
    * The channel that points to the version of the image you want.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.78.0/docs/data-sources/packer_iteration#channel DataHcpPackerIteration#channel}
    */
    readonly channel: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.78.0/docs/data-sources/packer_iteration#id DataHcpPackerIteration#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    *
    * The ID of the HCP project where the HCP Packer Registry is located.
    * If not specified, the project specified in the HCP Provider config block will be used, if configured.
    * If a project is not configured in the HCP Provider config block, the oldest project in the organization will be used.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.78.0/docs/data-sources/packer_iteration#project_id DataHcpPackerIteration#project_id}
    */
    readonly projectId?: string;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.78.0/docs/data-sources/packer_iteration#timeouts DataHcpPackerIteration#timeouts}
    */
    readonly timeouts?: DataHcpPackerIterationTimeouts;
}
export interface DataHcpPackerIterationTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.78.0/docs/data-sources/packer_iteration#default DataHcpPackerIteration#default}
    */
    readonly default?: string;
}
export declare function dataHcpPackerIterationTimeoutsToTerraform(struct?: DataHcpPackerIterationTimeouts | cdktf.IResolvable): any;
export declare class DataHcpPackerIterationTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): DataHcpPackerIterationTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: DataHcpPackerIterationTimeouts | cdktf.IResolvable | undefined);
    private _default?;
    get default(): string;
    set default(value: string);
    resetDefault(): void;
    get defaultInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/hcp/0.78.0/docs/data-sources/packer_iteration hcp_packer_iteration}
*/
export declare class DataHcpPackerIteration extends cdktf.TerraformDataSource {
    static readonly tfResourceType = "hcp_packer_iteration";
    /**
    * Generates CDKTF code for importing a DataHcpPackerIteration resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the DataHcpPackerIteration to import
    * @param importFromId The id of the existing DataHcpPackerIteration that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/hcp/0.78.0/docs/data-sources/packer_iteration#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the DataHcpPackerIteration to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/hcp/0.78.0/docs/data-sources/packer_iteration hcp_packer_iteration} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataHcpPackerIterationConfig
    */
    constructor(scope: Construct, id: string, config: DataHcpPackerIterationConfig);
    get authorId(): string;
    private _bucketName?;
    get bucketName(): string;
    set bucketName(value: string);
    get bucketNameInput(): string | undefined;
    private _channel?;
    get channel(): string;
    set channel(value: string);
    get channelInput(): string | undefined;
    get createdAt(): string;
    get fingerprint(): string;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get incrementalVersion(): number;
    get organizationId(): string;
    private _projectId?;
    get projectId(): string;
    set projectId(value: string);
    resetProjectId(): void;
    get projectIdInput(): string | undefined;
    get revokeAt(): string;
    get ulid(): string;
    get updatedAt(): string;
    private _timeouts;
    get timeouts(): DataHcpPackerIterationTimeoutsOutputReference;
    putTimeouts(value: DataHcpPackerIterationTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | DataHcpPackerIterationTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
