/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface HcpProviderConfig {
    /**
    * The OAuth2 Client ID for API operations.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.78.0/docs#client_id HcpProvider#client_id}
    */
    readonly clientId?: string;
    /**
    * The OAuth2 Client Secret for API operations.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.78.0/docs#client_secret HcpProvider#client_secret}
    */
    readonly clientSecret?: string;
    /**
    * The path to an HCP credential file to use to authenticate the provider to HCP. You can alternatively set the HCP_CRED_FILE environment variable to point at a credential file as well. Using a credential file allows you to authenticate the provider as a service principal via client credentials or dynamically based on Workload Identity Federation.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.78.0/docs#credential_file HcpProvider#credential_file}
    */
    readonly credentialFile?: string;
    /**
    * The default project in which resources should be created.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.78.0/docs#project_id HcpProvider#project_id}
    */
    readonly projectId?: string;
    /**
    * Alias name
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.78.0/docs#alias HcpProvider#alias}
    */
    readonly alias?: string;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/hcp/0.78.0/docs hcp}
*/
export declare class HcpProvider extends cdktf.TerraformProvider {
    static readonly tfResourceType = "hcp";
    /**
    * Generates CDKTF code for importing a HcpProvider resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the HcpProvider to import
    * @param importFromId The id of the existing HcpProvider that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/hcp/0.78.0/docs#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the HcpProvider to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/hcp/0.78.0/docs hcp} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options HcpProviderConfig = {}
    */
    constructor(scope: Construct, id: string, config?: HcpProviderConfig);
    private _clientId?;
    get clientId(): string | undefined;
    set clientId(value: string | undefined);
    resetClientId(): void;
    get clientIdInput(): string | undefined;
    private _clientSecret?;
    get clientSecret(): string | undefined;
    set clientSecret(value: string | undefined);
    resetClientSecret(): void;
    get clientSecretInput(): string | undefined;
    private _credentialFile?;
    get credentialFile(): string | undefined;
    set credentialFile(value: string | undefined);
    resetCredentialFile(): void;
    get credentialFileInput(): string | undefined;
    private _projectId?;
    get projectId(): string | undefined;
    set projectId(value: string | undefined);
    resetProjectId(): void;
    get projectIdInput(): string | undefined;
    private _alias?;
    get alias(): string | undefined;
    set alias(value: string | undefined);
    resetAlias(): void;
    get aliasInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
